@@ -1,6 +1,4 @@
 #
-# $Date: 2008/01/30 03:28:09 $
-#
 # Sort files based on their application type (content)
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -191,10 +189,10 @@ EOF2
 
     if (($::NSRLDB ne "") && (-e "$::NSRLDB")) {
 
-       # NSRL
-   		print
-   		  "<p><input type=\"checkbox\" name=\"sorter_nsrl\" value=\"1\" CHECKED>".
-   		  "Exclude files in the <b>NIST NSRL</b>\n";
+        # NSRL
+        print
+"<p><input type=\"checkbox\" name=\"sorter_nsrl\" value=\"1\" CHECKED>"
+          . "Exclude files in the <b>NIST NSRL</b>\n";
     }
 
     if (($Caseman::alert_db ne "") && (-e "$Caseman::alert_db")) {
@@ -261,7 +259,7 @@ sub run {
         if (   (exists $Args::args{'sorter_img'})
             && ($Args::args{'sorter_img'} == 1))
         {
-            my $config = "$::TSKDIR/../share/sorter/images.sort";
+            my $config = "$::TSKDIR/../share/tsk/sorter/images.sort";
 
             Print::print_err("images configuration file not found ($config)")
               unless (-e "$config");
@@ -284,7 +282,8 @@ sub run {
 
     if ($::NSRLDB ne "") {
         $sort_args .= "-n \'$::NSRLDB\' "
-          if ((exists $Args::args{'sorter_nsrl'}) && ($Args::args{'sorter_nsrl'} == 1));
+          if ( (exists $Args::args{'sorter_nsrl'})
+            && ($Args::args{'sorter_nsrl'} == 1));
     }
 
     if ($Caseman::alert_db ne "") {
