@@ -1,6 +1,4 @@
 #
-# $Date: 2007/12/21 18:05:16 $
-#
 # File name layer functions
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -144,11 +142,12 @@ my $SORT_NAME  = 2;
 my $SORT_MOD   = 3;
 my $SORT_ACC   = 4;
 my $SORT_CHG   = 5;
-my $SORT_SIZE  = 6;
-my $SORT_GID   = 7;
-my $SORT_UID   = 8;
-my $SORT_META  = 9;
-my $SORT_DEL   = 10;
+my $SORT_CRT   = 6;
+my $SORT_SIZE  = 7;
+my $SORT_GID   = 8;
+my $SORT_UID   = 9;
+my $SORT_META  = 10;
+my $SORT_DEL   = 11;
 
 my $DIRMODE_SHOW   = 1;
 my $DIRMODE_NOSHOW = 2;
@@ -360,8 +359,9 @@ sub dir_list {
               . Args::url_encode($lcldir . $fname . "/");
 
             print "<font color=\"$::DEL_COLOR[0]\">" if defined $del;
-            print
-"+$plus<a href=\"$url\" target=\"list\"><tt>/$fname</tt></a><br>\n";
+            print "+$plus<a href=\"$url\" target=\"list\"><tt>/"
+              . Print::html_encode($fname)
+              . "</tt></a><br>\n";
             print "</font>" if defined $del;
         }
     }
@@ -396,7 +396,8 @@ sub file_list {
 
     Print::print_html_header("Entries in $fname");
 
-    my (@itype, @dtype, @name, @mod, @acc, @chg, @size, @gid, @uid, @meta);
+    my (@itype, @dtype, @name, @mod, @acc, @chg, @crt, @size, @gid, @uid,
+        @meta);
     my (@dir, @entry, @del, @realloc, @meta_int);
 
     my $tz = "";
@@ -408,30 +409,28 @@ sub file_list {
     local *OUT;
 
     # execute command
-    # NTFS does not look at deleted files - it will use ifind later
-    if ($ftype eq "ntfs") {
-        Exec::exec_pipe(*OUT,
-"'$::TSKDIR/fls' -f $ftype -lau $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta"
-        );
-    }
-    else {
-        Exec::exec_pipe(*OUT,
+    Exec::exec_pipe(*OUT,
 "'$::TSKDIR/fls' -f $ftype -la $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta"
-        );
-    }
+    );
 
     # Make the big table, small table, and start the current directory
 
     my $iurl =
 "$::PROGNAME?$Args::baseargs&dirmode=$Args::enc_args{'dirmode'}&sort=$sort";
 
+    # base number of columns in table
+    my $cols = 15;
+    $cols += 2 if ($Fs::has_ctime{$ftype});
+    $cols += 2 if ($Fs::has_crtime{$ftype});
+    $cols += 2 if ($Fs::has_mtime{$ftype});
+
     print <<EOF1;
 <!-- Big Table -->
 <table cellspacing=\"0\" cellpadding=\"2\" border=0>
 
 <!-- Small Table -->
 <tr>
-  <td colspan=19>
+  <td colspan=$cols>
     <table border=0 align=\"left\" cellspacing=\"0\" cellpadding=\"2\" width=500>
     <tr>
       <td colspan=2><b>Current Directory:</b> <tt>
@@ -487,7 +486,7 @@ EOF2
   </td>
 </tr>
 <tr>
-  <td colspan=19><hr></td>
+  <td colspan=$cols><hr></td>
 </tr>
 
 EOF3
@@ -568,43 +567,28 @@ EOF3
     print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
 
     # Modified / Written
-    if ($sort == $SORT_MOD) {
-        print "  <td align=\"left\" background=\"$::YEL_PIX\">";
-        if ($Fs::mtime_str{$ftype} eq 'Modified') {
-            print "<img border=\"0\" "
-              . "src=\"pict/file_h_mod_cur.jpg\" "
-              . "width=\"84\" height=20 "
-              . "alt=\"Modified Time\">";
-        }
-        else {
-            print "<img border=\"0\" "
+    if ($Fs::has_mtime{$ftype}) {
+        if ($sort == $SORT_MOD) {
+            print "  <td align=\"left\" background=\"$::YEL_PIX\">"
+              . "<img border=\"0\" "
               . "src=\"pict/file_h_wr_cur.jpg\" "
               . "width=\"89\" height=20 "
-              . "alt=\"Written Time\">";
-        }
-        print "</td>\n";
-    }
-    else {
-        $iurl = $url . "&sort=$SORT_MOD";
-        print "  <td align=\"left\" background=\"$::YEL_PIX\">"
-          . "<a href=\"$iurl\" target=\"_parent\">";
-        if ($Fs::mtime_str{$ftype} eq 'Modified') {
-            print "<img border=\"0\" "
-              . "src=\"pict/file_h_mod_link.jpg\" "
-              . "width=\"62\" height=20 "
-              . "alt=\"Modified Time\">";
+              . "alt=\"Modified/Written Time\">"
+              . "</td>\n";
         }
         else {
-            print "<img border=\"0\" "
+            $iurl = $url . "&sort=$SORT_MOD";
+            print "  <td align=\"left\" background=\"$::YEL_PIX\">"
+              . "<a href=\"$iurl\" target=\"_parent\">"
+              . "<img border=\"0\" "
               . "src=\"pict/file_h_wr_link.jpg\" "
               . "width=\"60\" height=20 "
-              . "alt=\"Written Time\">";
+              . "alt=\"Modified/Written Time\">"
+              . "</a></td>\n";
         }
-        print "</a></td>\n";
+        print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
     }
 
-    print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
-
     # Accessed
     if ($sort == $SORT_ACC) {
         print "  <td align=\"left\" background=\"$::YEL_PIX\">"
@@ -627,43 +611,51 @@ EOF3
 
     print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
 
-    # Change / Create
-    if ($sort == $SORT_CHG) {
-        print "  <td align=\"left\" background=\"$::YEL_PIX\">";
-        if ($Fs::ctime_str{$ftype} eq 'Changed') {
-            print "<img border=\"0\" "
+    # Change
+    if ($Fs::has_ctime{$ftype}) {
+        if ($sort == $SORT_CHG) {
+            print "  <td align=\"left\" background=\"$::YEL_PIX\">"
+              . "<img border=\"0\" "
               . "src=\"pict/file_h_chg_cur.jpg\" "
               . "width=\"90\" height=20 "
-              . "alt=\"Change Time\">";
+              . "alt=\"Change Time\">"
+              . "</td>\n";
         }
         else {
-            print "<img border=\"0\" "
-              . "src=\"pict/file_h_cre_cur.jpg\" "
-              . "width=\"84\" height=20 "
-              . "alt=\"Create Time\">";
-        }
-        print "</td>\n";
-    }
-    else {
-        $iurl = $url . "&sort=$SORT_CHG";
-        print "  <td align=\"left\" background=\"$::YEL_PIX\">"
-          . "<a href=\"$iurl\" target=\"_parent\">";
-        if ($Fs::ctime_str{$ftype} eq 'Changed') {
-            print "<img border=\"0\" "
+            $iurl = $url . "&sort=$SORT_CHG";
+            print "  <td align=\"left\" background=\"$::YEL_PIX\">"
+              . "<a href=\"$iurl\" target=\"_parent\">"
+              . "<img border=\"0\" "
               . "src=\"pict/file_h_chg_link.jpg\" "
               . "width=\"62\" height=20 "
-              . "alt=\"Change Time\">";
+              . "alt=\"Change Time\">"
+              . "</a></td>\n";
         }
-        else {
-            print "<img border=\"0\" "
-              . "src=\"pict/file_h_cre_link.jpg\" "
-              . "width=\"59\" height=20 "
-              . "alt=\"Create Time\">";
-        }
-        print "</a></td>\n";
+        print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
     }
 
-    print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
+    # Create
+    if ($Fs::has_crtime{$ftype}) {
+        if ($sort == $SORT_CRT) {
+            print "  <td align=\"left\" background=\"$::YEL_PIX\">"
+              . "<img border=\"0\" "
+              . "src=\"pict/file_h_cre_cur.jpg\" "
+              . "width=\"84\" height=20 "
+              . "alt=\"Create Time\">"
+              . "</td>\n";
+        }
+        else {
+            $iurl = $url . "&sort=$SORT_CRT";
+            print "  <td align=\"left\" background=\"$::YEL_PIX\">"
+              . "<a href=\"$iurl\" target=\"_parent\">"
+              . "<img border=\"0\" "
+              . "src=\"pict/file_h_cre_link.jpg\" "
+              . "width=\"59\" height=20 "
+              . "alt=\"Create Time\">"
+              . "</a></td>\n";
+        }
+        print "  <td background=\"$::YEL_PIX\">$sp</td>\n";
+    }
 
     # Size
     if ($sort == $SORT_SIZE) {
@@ -755,10 +747,10 @@ EOF3
     my $cnt = 0;
     my %seen;
 
-    # sort into arrays
+    # sort fls into arrays
     while ($_ = Exec::read_pipe_line(*OUT)) {
         if (
-/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
+/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
           )
         {
 
@@ -773,9 +765,10 @@ EOF3
             $mod[$cnt]     = $7;
             $acc[$cnt]     = $8;
             $chg[$cnt]     = $9;
-            $size[$cnt]    = $10;
-            $gid[$cnt]     = $11;
-            $uid[$cnt]     = $12;
+            $crt[$cnt]     = $10;
+            $size[$cnt]    = $11;
+            $gid[$cnt]     = $12;
+            $uid[$cnt]     = $13;
 
             if ($meta[$cnt] =~ /^(\d+)(-\d+(-\d+)?)?$/) {
                 $meta_int[$cnt] = $1;
@@ -835,6 +828,9 @@ EOF3
             $chg[$cnt] = "$1&nbsp;$2"
               if ($chg[$cnt] =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
 
+            $crt[$cnt] = "$1&nbsp;$2"
+              if ($crt[$cnt] =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
+
             $dir[$cnt]   = Args::url_encode($lcldir);
             $entry[$cnt] = $cnt;
             $cnt++;
@@ -849,102 +845,6 @@ EOF3
     }
     close(OUT);
 
-    # ntfs runs 'ifind' to find the orphan MFT entries
-    if ($ftype eq "ntfs") {
-
-        Exec::exec_pipe(*OUT,
-"'$::TSKDIR/ifind' -f $ftype -l $tz -p $meta -o $offset -i $imgtype $img"
-        );
-
-        while ($_ = Exec::read_pipe_line(*OUT)) {
-            if (
-/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
-              )
-            {
-
-                my $lcldir = $Args::args{'dir'};
-                $dtype[$cnt]   = $1;
-                $itype[$cnt]   = $2;
-                $del[$cnt]     = $3;
-                $meta[$cnt]    = $4;
-                $realloc[$cnt] = "";
-                $realloc[$cnt] = $5 if (defined $5);
-                $name[$cnt]    = $6;
-                $mod[$cnt]     = $7;
-                $acc[$cnt]     = $8;
-                $chg[$cnt]     = $9;
-                $size[$cnt]    = $10;
-                $gid[$cnt]     = $11;
-                $uid[$cnt]     = $12;
-
-                if ($meta[$cnt] =~ /^(\d+)(-\d+(-\d+)?)?$/) {
-                    $meta_int[$cnt] = $1;
-                }
-                else {
-                    $meta_int[$cnt] = $meta[$cnt];
-                }
-
-                # See if we have already seen this file yet
-                if (exists $seen{"$name[$cnt]-$meta[$cnt]"}) {
-                    next;
-
-                    # Add it to the seen list
-                }
-                else {
-                    $seen{"$name[$cnt]-$meta[$cnt]"} = $cnt;
-                }
-
-                # We must adjust the dir for directories
-                if ($itype[$cnt] eq 'd') {
-
-                    # special cases for .. and .
-                    if ($name[$cnt] eq '..') {
-                        my @dirs = split('/', $lcldir);
-                        my $i;
-                        $lcldir = "";
-                        for ($i = 0; $i < $#dirs; $i++) {
-                            $lcldir .= ($dirs[$i] . '/');
-                        }
-                    }
-                    elsif ($name[$cnt] ne '.') {
-                        $lcldir .= ($name[$cnt] . '/');
-                    }
-                    $name[$cnt] .= '/';
-                }
-                else {
-                    $lcldir .= $name[$cnt];
-                }
-
-                # format the date so that the time and time zone are on the
-                # same line
-                $mod[$cnt] = "$1&nbsp;$2"
-                  if ($mod[$cnt] =~
-                    /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
-
-                $acc[$cnt] = "$1&nbsp;$2"
-                  if ($acc[$cnt] =~
-                    /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
-
-                $chg[$cnt] = "$1&nbsp;$2"
-                  if ($chg[$cnt] =~
-                    /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
-
-                $dir[$cnt]   = Args::url_encode($lcldir);
-                $entry[$cnt] = $cnt;
-                $cnt++;
-
-            }
-
-            # We missed it for some reason
-            else {
-                print
-"<tr><td colspan=10>Error Parsing File (Invalid Characters?):<br>$_</td></tr>\n";
-            }
-        }
-        close(OUT);
-
-    }    # End NTFS ONLY
-
     if ($cnt == 0) {
         print "</table>\n<center>No Contents</center>\n";
         return 0;
@@ -981,6 +881,11 @@ EOF3
           sort { $chg[$a] cmp $chg[$b] or lc($name[$a]) cmp lc($name[$b]) }
           @entry;
     }
+    elsif ($sort == $SORT_CRT) {
+        @sorted =
+          sort { $crt[$a] cmp $crt[$b] or lc($name[$a]) cmp lc($name[$b]) }
+          @entry;
+    }
     elsif ($sort == $SORT_SIZE) {
         @sorted =
           sort { $size[$a] <=> $size[$b] or lc($name[$a]) cmp lc($name[$b]) }
@@ -1065,24 +970,32 @@ EOF3
           . "  <td>$sp</td>\n";
 
         # for valid files and directories make a link
-        if (   ($meta_int[$i] >= $Fs::first_meta{$ftype})
-            && ($size[$i] > 0)
-            && (($itype[$i] eq 'r') || ($itype[$i] eq 'd')))
+        # Special rule for $OrphanFiles directory, which has a size of 0
+        if (
+               ($meta_int[$i] >= $Fs::first_meta{$ftype})
+            && (($size[$i] > 0) || ($name[$i] =~ /^\$Orphan/))
+            && (   ($itype[$i] eq 'r')
+                || ($itype[$i] eq 'd')
+                || ($itype[$i] eq 'v'))
+          )
         {
             print "  <td><a href=\"$url\" target=\"$target\">$lcolor";
         }
         else {
             print "  <td>$color";
         }
-        print "<tt>$name[$i]</tt></td>\n"
-          . "  <td>$sp</td>\n"
-          . "  <td>${color}$mod[$i]</td>\n"
-          . "  <td>$sp</td>\n"
-          . "  <td>${color}$acc[$i]</td>\n"
-          . "  <td>$sp</td>\n"
-          . "  <td>${color}$chg[$i]</td>\n"
-          . "  <td>$sp</td>\n"
-          . "  <td>${color}$size[$i]</td>\n"
+        print "<tt>"
+          . Print::html_encode($name[$i])
+          . "</tt></td>\n"
+          . "  <td>$sp</td>\n";
+        print "  <td>${color}$mod[$i]</td>\n" . "  <td>$sp</td>\n"
+          if ($Fs::has_mtime{$ftype});
+        print "  <td>${color}$acc[$i]</td>\n" . "  <td>$sp</td>\n";
+        print "  <td>${color}$chg[$i]</td>\n" . "  <td>$sp</td>\n"
+          if ($Fs::has_ctime{$ftype});
+        print "  <td>${color}$crt[$i]</td>\n" . "  <td>$sp</td>\n"
+          if ($Fs::has_crtime{$ftype});
+        print "  <td>${color}$size[$i]</td>\n"
           . "  <td>$sp</td>\n"
           . "  <td>${color}$uid[$i]</td>\n"
           . "  <td>$sp</td>\n"
@@ -1138,11 +1051,10 @@ sub file_list_dir {
     }
     close(OUT);
 
-    Print::print_check_err("Error finding meta data address for <tt>$dir</tt>")
+    Print::print_check_err("Error finding meta data address for $dir")
       unless (defined $meta);
 
-    Print::print_check_err(
-        "Error finding meta data address for <tt>$dir</TT<: $meta")
+    Print::print_check_err("Error finding meta data address for $dir: $meta")
       unless ($meta =~ /^$::REG_META$/);
 
     # Verify it is a directory with istat
@@ -1281,18 +1193,14 @@ sub file_list_file {
       . "<td>$sp</td>\n";
 
     # Mod / Written
-    print "  <td><img border=\"0\" ";
-    if ($Fs::mtime_str{$ftype} eq 'Modified') {
-        print "src=\"pict/file_h_mod_link.jpg\" "
-          . "width=\"62\" height=20 "
-          . "alt=\"Modified Time\">";
-    }
-    else {
-        print "src=\"pict/file_h_wr_link.jpg\" "
+    if ($Fs::has_mtime{$ftype}) {
+        print "  <td><img border=\"0\" "
+          . "src=\"pict/file_h_wr_link.jpg\" "
           . "width=\"60\" "
-          . "alt=\"Written Time\">";
+          . "alt=\"Written Time\">"
+          . "</td>\n"
+          . "<td>$sp</td>\n";
     }
-    print "</td>\n" . "<td>$sp</td>\n";
 
     # Access
     print "  <td><img border=\"0\" "
@@ -1302,19 +1210,25 @@ sub file_list_file {
       . "</td>\n"
       . "<td>$sp</td>\n";
 
-    # Change / Create
-    print "  <td><img border=\"0\" ";
-    if ($Fs::ctime_str{$ftype} eq 'Changed') {
-        print "src=\"pict/file_h_chg_link.jpg\" "
-          . "width=\"62\" height=20 "
-          . "alt=\"Change Time\">";
+    # Change
+    if ($Fs::has_ctime{$ftype}) {
+        print "  <td><img border=\"0\" "
+          . "src=\"pict/file_h_chg_link.jpg\" "
+          . "width=\"62\" "
+          . "alt=\"Change Time\">"
+          . "</td>\n"
+          . "<td>$sp</td>\n";
     }
-    else {
-        print "src=\"pict/file_h_cre_link.jpg\" "
-          . "width=\"59\" height=20 "
-          . "alt=\"Create Time\">";
+
+    # Create
+    if ($Fs::has_crtime{$ftype}) {
+        print "  <td><img border=\"0\" "
+          . "src=\"pict/file_h_cre_link.jpg\" "
+          . "width=\"59\" "
+          . "alt=\"Create Time\">"
+          . "</td>\n"
+          . "<td>$sp</td>\n";
     }
-    print "</td>\n" . "<td>$sp</td>\n";
 
     # Size
     print "  <td><img border=\"0\" "
@@ -1350,9 +1264,8 @@ sub file_list_file {
 
     my $row = 0;
     while ($_ = Exec::read_pipe_line(*OUT)) {
-
         if (
-/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
+/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
           )
         {
 
@@ -1364,13 +1277,14 @@ sub file_list_file {
             my $i  = $4;
             my $r  = 0;
             $r = 1 if (defined $5);
-            my $n = $6;
-            my $m = $7;
-            my $a = $8;
-            my $c = $9;
-            my $s = $10;
-            my $g = $11;
-            my $u = $12;
+            my $n  = $6;
+            my $m  = $7;
+            my $a  = $8;
+            my $c  = $9;
+            my $cr = $10;
+            my $s  = $11;
+            my $g  = $12;
+            my $u  = $13;
 
             if ($n =~ /^\/(.*)/) {
                 $n = $1;
@@ -1435,7 +1349,10 @@ sub file_list_file {
                 else {
                     print "$color";
                 }
-                print "<tt>$mnt$n</tt></td>" . "<td>$sp</td>\n";
+                print "<tt>"
+                  . Print::html_encode($mnt . $n)
+                  . "</tt></td>"
+                  . "<td>$sp</td>\n";
             }
             else {
                 my $url =
@@ -1465,14 +1382,19 @@ sub file_list_file {
               if ($a =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
             $c = "$1&nbsp;$2"
               if ($c =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
+            $cr = "$1&nbsp;$2"
+              if ($cr =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
 
-            print "<td>$color$m</td>"
-              . "<td>$sp</td>\n"
-              . "<td>$color$a</td>"
-              . "<td>$sp</td>\n"
-              . "<td>$color$c</td>"
-              . "<td>$sp</td>\n"
-              . "<td>$color$s</td>"
+            print "<td>$color$m</td>" . "<td>$sp</td>\n"
+              if ($Fs::has_mtime{$ftype});
+
+            print "<td>$color$a</td>" . "<td>$sp</td>\n";
+            print "<td>$color$c</td>" . "<td>$sp</td>\n"
+              if ($Fs::has_ctime{$ftype});
+            print "<td>$color$cr</td>" . "<td>$sp</td>\n"
+              if ($Fs::has_crtime{$ftype});
+
+            print "<td>$color$s</td>"
               . "<td>$sp</td>\n"
               . "<td>$color$g</td>"
               . "<td>$sp</td>\n"
@@ -1557,18 +1479,14 @@ sub file_list_del {
       . "<td>$sp</td>\n";
 
     # Mod / Written
-    print "  <td><img border=\"0\" ";
-    if ($Fs::mtime_str{$ftype} eq 'Modified') {
-        print "src=\"pict/file_h_mod_link.jpg\" "
-          . "width=\"62\" height=20 "
-          . "alt=\"Modified Time\">";
-    }
-    else {
-        print "src=\"pict/file_h_wr_link.jpg\" "
+    if ($Fs::has_mtime{$ftype}) {
+        print "  <td><img border=\"0\" "
+          . "src=\"pict/file_h_wr_link.jpg\" "
           . "width=\"60\" "
-          . "alt=\"Written Time\">";
+          . "alt=\"Written Time\">"
+          . "</td>\n"
+          . "<td>$sp</td>\n";
     }
-    print "</td>\n" . "<td>$sp</td>\n";
 
     # Access
     print "  <td><img border=\"0\" "
@@ -1578,19 +1496,25 @@ sub file_list_del {
       . "</td>\n"
       . "<td>$sp</td>\n";
 
-    # Change / Create
-    print "  <td><img border=\"0\" ";
-    if ($Fs::ctime_str{$ftype} eq 'Changed') {
-        print "src=\"pict/file_h_chg_link.jpg\" "
-          . "width=\"62\" height=20 "
-          . "alt=\"Change Time\">";
+    # Change
+    if ($Fs::has_ctime{$ftype}) {
+        print "  <td><img border=\"0\" "
+          . "src=\"pict/file_h_chg_link.jpg\" "
+          . "width=\"62\" "
+          . "alt=\"Change Time\">"
+          . "</td>\n"
+          . "<td>$sp</td>\n";
     }
-    else {
-        print "src=\"pict/file_h_cre_link.jpg\" "
-          . "width=\"59\" height=20 "
-          . "alt=\"Create Time\">";
+
+    # Create
+    if ($Fs::has_crtime{$ftype}) {
+        print "  <td><img border=\"0\" "
+          . "src=\"pict/file_h_cre_link.jpg\" "
+          . "width=\"59\" "
+          . "alt=\"Create Time\">"
+          . "</td>\n"
+          . "<td>$sp</td>\n";
     }
-    print "</td>\n" . "<td>$sp</td>\n";
 
     # Size
     print "  <td><img border=\"0\" "
@@ -1628,7 +1552,7 @@ sub file_list_del {
     while ($_ = Exec::read_pipe_line(*OUT)) {
 
         if (
-/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
+/^($::REG_MTYPE)\/($::REG_MTYPE)\s*(\*?)\s*($::REG_META)(\(realloc\))?:\t(.+?)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t($::REG_DATE)\t(\d+)\t(\d+)\t(\d+)$/o
           )
         {
 
@@ -1640,13 +1564,14 @@ sub file_list_del {
             my $i  = $4;
             my $r  = 0;
             $r = 1 if (defined $5);
-            my $n = $6;
-            my $m = $7;
-            my $a = $8;
-            my $c = $9;
-            my $s = $10;
-            my $g = $11;
-            my $u = $12;
+            my $n  = $6;
+            my $m  = $7;
+            my $a  = $8;
+            my $c  = $9;
+            my $cr = $10;
+            my $s  = $11;
+            my $g  = $12;
+            my $u  = $13;
 
             if ($n =~ /^\/(.*)/) {
                 $n = $1;
@@ -1679,7 +1604,8 @@ sub file_list_del {
                     print "<a href=\"$url\" target=\"_self\">";
                 }
                 print "<font color=\"$::DEL_COLOR[$r]\"><tt>"
-                  . "$mnt$n</tt></td>"
+                  . Print::html_encode($mnt . $n)
+                  . "</tt></td>"
                   . "<td>$sp</td>\n";
             }
             else {
@@ -1693,7 +1619,8 @@ sub file_list_del {
                     print "<a href=\"$url\" target=\"content\">";
                 }
                 print "<font color=\"$::DEL_COLOR[$r]\"><tt>"
-                  . "$mnt$n</tt></td>"
+                  . Print::html_encode($mnt . $n)
+                  . "</tt></td>"
                   . "<td>$sp</td>\n";
             }
 
@@ -1703,14 +1630,23 @@ sub file_list_del {
               if ($a =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
             $c = "$1&nbsp;$2"
               if ($c =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
+            $cr = "$1&nbsp;$2"
+              if ($cr =~ /($::REG_DAY\s+$::REG_TIME)\s+($::REG_ZONE2)/o);
 
             print "<td><font color=\"$::DEL_COLOR[$r]\">$m</td>"
               . "<td>$sp</td>\n"
-              . "<td><font color=\"$::DEL_COLOR[$r]\">$a</td>"
+              if ($Fs::has_mtime{$ftype});
+
+            print "<td><font color=\"$::DEL_COLOR[$r]\">$a</td>"
+              . "<td>$sp</td>\n";
+            print "<td><font color=\"$::DEL_COLOR[$r]\">$c</td>"
               . "<td>$sp</td>\n"
-              . "<td><font color=\"$::DEL_COLOR[$r]\">$c</td>"
+              if ($Fs::has_ctime{$ftype});
+            print "<td><font color=\"$::DEL_COLOR[$r]\">$cr</td>"
               . "<td>$sp</td>\n"
-              . "<td><font color=\"$::DEL_COLOR[$r]\">$s</td>"
+              if ($Fs::has_crtime{$ftype});
+
+            print "<td><font color=\"$::DEL_COLOR[$r]\">$s</td>"
               . "<td>$sp</td>\n"
               . "<td><font color=\"$::DEL_COLOR[$r]\">$g</td>"
               . "<td>$sp</td>\n"
@@ -2159,7 +2095,7 @@ sub report {
 
     if ($::SHA1_EXE ne "") {
         Exec::exec_pipe(*OUT,
-    "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
         );
         my $sha1 = Exec::read_pipe_line(*OUT);
         close(OUT);
@@ -2191,7 +2127,7 @@ sub report {
 
         if ($::SHA1_EXE ne "") {
             Exec::exec_pipe(*OUT,
-    "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a | '$::SHA1_EXE'"
+"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a | '$::SHA1_EXE'"
             );
             $sha1 = Exec::read_pipe_line(*OUT);
             close(OUT);
@@ -2226,7 +2162,7 @@ sub report {
     Exec::exec_pipe(*OUT,
 "'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta"
     );
-    print "$_" while ($_ = Exec::read_pipe_line(*OUT));
+    print $_ while ($_ = Exec::read_pipe_line(*OUT));
     close(OUT);
 
     # File Type
@@ -2339,7 +2275,7 @@ sub md5list {
               if ((!defined $md5out) || ($md5out eq ""));
 
             chomp $md5out;
-            print "$md5out\t$name\n";
+            print "$md5out\t" . Print::html_encode($name) . "\n";
             close(OUT_MD5);
         }
         elsif (/[\w\-]\/[\w\-]\s+([\d\-]+):\s+(.*)$/) {
