@@ -1,6 +1,4 @@
 #
-# $Date: 2005/03/16 00:03:40 $
-#
 # Keyword search mode
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -93,7 +91,7 @@ sub enter {
     Print::print_html_header("Search on $Caseman::vol2sname{$vol}");
     my $ftype = $Caseman::vol2ftype{$vol};
 
-    if ($ftype eq 'dls') {
+    if ($ftype eq 'blkls') {
         print "<center><h3>Keyword Search of Unallocated Space</h3>\n";
     }
     elsif ($ftype eq 'swap') {
@@ -113,7 +111,7 @@ sub enter {
     # @@@ Fix this - caused by writing all results to a file
     if ($::LIVE == 1) {
         Print::print_err(
-"<center>Keyword searching is temporarily not available during live analysis mode</center>"
+"Keyword searching is temporarily not available during live analysis mode"
         );
     }
 
@@ -139,20 +137,20 @@ sub enter {
     if ($::LIVE == 0) {
         print "<table width=600><tr>\n";
 
-        # If we are a non-dls image and one exists - make a button to load it
-        if (($ftype ne 'dls') && (exists $Caseman::vol2dls{$vol})) {
+        # If we are a non-blkls image and one exists - make a button to load it
+        if (($ftype ne 'blkls') && (exists $Caseman::vol2blkls{$vol})) {
             print "<td align=center width=200>"
               . "<form action=\"$::PROGNAME\" method=\"get\" target=\"_top\">\n"
               . "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FRAME\">\n"
               . "<input type=\"hidden\" name=\"submod\" value=\"$::MOD_KWSRCH\">\n"
-              . "<input type=\"hidden\" name=\"vol\" value=\"$Caseman::vol2dls{$vol}\">\n"
+              . "<input type=\"hidden\" name=\"vol\" value=\"$Caseman::vol2blkls{$vol}\">\n"
               . Args::make_hidden()
               . "<input type=\"image\" src=\"pict/srch_b_lun.jpg\" "
               . "alt=\"Load Unallocated Image\" border=\"0\">\n<br></form></td>\n";
         }
 
-        # If we are a dls and the original exists - make a button to load it
-        elsif (($ftype eq 'dls')
+        # If we are a blkls and the original exists - make a button to load it
+        elsif (($ftype eq 'blkls')
             && (exists $Caseman::mod2vol{$vol}))
         {
             print "<td align=center width=200>"
@@ -186,7 +184,7 @@ sub enter {
 
         # Unallocated Space Button
         if (   ($Fs::is_fs{$ftype})
-            && (!(exists $Caseman::vol2dls{$vol})))
+            && (!(exists $Caseman::vol2blkls{$vol})))
         {
             print "<td align=center width=200>"
               . "<form action=\"$::PROGNAME\" method=\"get\" target=\"_top\">\n"
@@ -566,7 +564,7 @@ sub run {
                     && ($Caseman::vol2end{$vol} != 0))
                 {
                     Exec::exec_pipe(*OUT,
-                            "'$::TSKDIR/dls' -e -f $ftype -i $imgtype $img "
+                            "'$::TSKDIR/blkls' -e -f $ftype -i $imgtype $img "
                           . $Caseman::vol2start{$vol} . "-"
                           . $Caseman::vol2end{$vol}
                           . " | '$::TSKDIR/srch_strings' -a -t d -$ltmp | '$::GREP_EXE' $grep_flag '$grep_str'"
@@ -574,7 +572,7 @@ sub run {
                 }
                 else {
                     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d -$ltmp | '$::GREP_EXE' $grep_flag '$grep_str'"
+"'$::TSKDIR/blkls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d -$ltmp | '$::GREP_EXE' $grep_flag '$grep_str'"
                     );
                 }
             }
@@ -584,7 +582,7 @@ sub run {
                     && ($Caseman::vol2end{$vol} != 0))
                 {
                     Exec::exec_pipe(*OUT,
-                            "'$::TSKDIR/dls' -e -f $ftype -i $imgtype $img "
+                            "'$::TSKDIR/blkls' -e -f $ftype -i $imgtype $img "
                           . $Caseman::vol2start{$vol} . "-"
                           . $Caseman::vol2end{$vol}
                           . " | '$::TSKDIR/srch_strings' -a -t d -e l -$ltmp | '$::GREP_EXE' $grep_flag '$grep_str'"
@@ -592,7 +590,7 @@ sub run {
                 }
                 else {
                     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d -e l -$ltmp | '$::GREP_EXE' $grep_flag '$grep_str'"
+"'$::TSKDIR/blkls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d -e l -$ltmp | '$::GREP_EXE' $grep_flag '$grep_str'"
                     );
                 }
             }
@@ -617,7 +615,7 @@ sub run {
                     && ($Caseman::vol2end{$vol} != 0))
                 {
                     Exec::exec_pipe(*OUT,
-                            "'$::TSKDIR/dls' -e -f $ftype -i $imgtype $img "
+                            "'$::TSKDIR/blkls' -e -f $ftype -i $imgtype $img "
                           . $Caseman::vol2start{$vol} . "-"
                           . $Caseman::vol2end{$vol}
                           . " | '$::TSKDIR/srch_strings' -a -t d | '$::GREP_EXE' $grep_flag '$grep_str'"
@@ -625,7 +623,7 @@ sub run {
                 }
                 else {
                     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d | '$::GREP_EXE' $grep_flag '$grep_str'"
+"'$::TSKDIR/blkls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d | '$::GREP_EXE' $grep_flag '$grep_str'"
                     );
                 }
             }
@@ -634,7 +632,7 @@ sub run {
                     && ($Caseman::vol2end{$vol} != 0))
                 {
                     Exec::exec_pipe(*OUT,
-                            "'$::TSKDIR/dls' -e -f $ftype -i $imgtype $img "
+                            "'$::TSKDIR/blkls' -e -f $ftype -i $imgtype $img "
                           . $Caseman::vol2start{$vol} . "-"
                           . $Caseman::vol2end{$vol}
                           . " | '$::TSKDIR/srch_strings' -a -t d -e l | '$::GREP_EXE' $grep_flag '$grep_str'"
@@ -642,7 +640,7 @@ sub run {
                 }
                 else {
                     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d -e l | '$::GREP_EXE' $grep_flag '$grep_str'"
+"'$::TSKDIR/blkls' -e -f $ftype -o $offset -i $imgtype $img | '$::TSKDIR/srch_strings' -a -t d -e l | '$::GREP_EXE' $grep_flag '$grep_str'"
                     );
                 }
             }
@@ -923,8 +921,8 @@ sub print_srch_results {
             print
 " - <a href=\"$::PROGNAME?$Args::baseargs&mod=$::MOD_DATA&view=$Data::CONT_MENU_FR&"
               . "mnt=$Args::enc_args{'mnt'}&vol=$Caseman::mod2vol{$vol}&"
-              . "btype=$Data::ADDR_DLS&block=$blk\" target=content>Original</a>"
-              if ( ($ftype eq 'dls')
+              . "btype=$Data::ADDR_BLKLS&block=$blk\" target=content>Original</a>"
+              if ( ($ftype eq 'blkls')
                 && (exists $Caseman::mod2vol{$vol}));
 
             print ")<br>";
