@@ -1,6 +1,4 @@
 #
-# $Date: 2007/12/21 18:05:17 $
-#
 # Metadata mode
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -268,15 +266,17 @@ sub stats {
         while ($_ = Exec::read_pipe_line(*OUT)) {
             chop;
             if (/^(\*)\s+\/*(.*)$/) {
-                Print::print_output(
-"<tt><font color=\"$::DEL_COLOR[0]\">$tmpr$2</font></tt> (deleted)<br><br>\n"
-                );
+                Print::print_output("<tt><font color=\"$::DEL_COLOR[0]\">"
+                      . Print::html_encode($tmpr . $2)
+                      . "</font></tt> (deleted)<br><br>\n");
             }
             elsif (/^\/(.*)$/) {
-                Print::print_output("<tt>$tmpr$1</tt><br><br>\n");
+                Print::print_output("<tt>"
+                      . Print::html_encode($tmpr . $1)
+                      . "</tt><br><br>\n");
             }
             else {
-                Print::print_output("$_<br><br>\n");
+                Print::print_output(Print::html_encode($_) . "<br><br>\n");
             }
             $cnt++;
         }
@@ -379,12 +379,12 @@ sub stats {
     if ($::SHA1_EXE ne "") {
         if ($recmode == $File::REC_YES) {
             Exec::exec_pipe(*OUT,
-    "'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+"'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
             );
         }
         else {
             Exec::exec_pipe(*OUT,
-    "'$::TSKDIR/icat' -f $ftype -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+"'$::TSKDIR/icat' -f $ftype -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
             );
         }
 
@@ -397,7 +397,7 @@ sub stats {
         chomp $sha1out;
         if ($recmode == $File::REC_YES) {
             print
-              "<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br><br>\n";
+"<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br><br>\n";
         }
         else {
             print "<b>SHA-1 of content:</b><br><tt>$sha1out</tt><br><br>\n";
@@ -510,15 +510,16 @@ sub findfile {
     while ($_ = Exec::read_pipe_line(*OUT)) {
         chop;
         if (/(\*)\s+\/*(.*)/) {
-            Print::print_output(
-"<tt><font color=\"$::DEL_COLOR[0]\">$tmpr$2</font></tt> (deleted)<br>\n"
-            );
+            Print::print_output("<tt><font color=\"$::DEL_COLOR[0]\">"
+                  . Print::html_encode($tmpr . $2)
+                  . "</font></tt> (deleted)<br>\n");
         }
         elsif (/^\/(.*)$/) {
-            Print::print_output("<tt>$tmpr$1</tt><br>\n");
+            Print::print_output(
+                "<tt>" . Print::html_encode($tmpr . $1) . "</tt><br>\n");
         }
         else {
-            Print::print_output("$_<br>\n");
+            Print::print_output(Print::html_encode($_) . "<br>\n");
         }
     }
     close(OUT);
@@ -591,10 +592,11 @@ sub report {
     while ($_ = Exec::read_pipe_line(*OUT)) {
         chop;
         if (/^(\*)\s+\/*(.*)$/) {
-            Print::print_output("  $tmpr$2 (deleted)\n");
+            Print::print_output(
+                "  ${tmpr}${2} (deleted)\n");
         }
         elsif (/^\/(.*)$/) {
-            Print::print_output("  $tmpr$1\n");
+            Print::print_output("  ${tmpr}${1}\n");
         }
         else {
             Print::print_output("  $_\n");
@@ -616,7 +618,7 @@ sub report {
 
     if ($::SHA1_EXE ne "") {
         Exec::exec_pipe(*OUT,
-    "'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+"'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
         );
         my $sha1 = Exec::read_pipe_line(*OUT);
         close(OUT);
@@ -650,7 +652,7 @@ sub report {
 "'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta"
     );
     while ($_ = Exec::read_pipe_line(*OUT)) {
-        print "$_";
+        print $_;
     }
     close(OUT);
 
