@@ -1,6 +1,4 @@
 #
-# $Date: 2007/04/19 21:25:17 $
-#
 # Notes and sequencer functions
 #
 # Brian Carrier [carrier@sleuthkit.org]
@@ -146,7 +144,8 @@ sub enter_file {
     $meta_int = $1 if ($meta_int =~ /^(\d+)-\d+(-\d+)?$/);
     local *OUT;
     Exec::exec_pipe(*OUT,
-        "'$::TSKDIR/ils' -s $Caseman::ts -f $ftype -e  -o $offset -i $imgtype $img $meta_int");
+"'$::TSKDIR/ils' -s $Caseman::ts -f $ftype -e  -o $offset -i $imgtype $img $meta_int"
+    );
 
     # Get the fourth line
     my $tmp = Exec::read_pipe_line(*OUT);
@@ -157,7 +156,7 @@ sub enter_file {
     unless ((defined $tmp)
         && ($tmp =~ /^$::REG_META\|\w\|\d+\|\d+\|(\d+)\|(\d+)\|(\d+)\|/o))
     {
-        Print::print_err("Error parsing 'ils' output<br>");
+        Print::print_err("Error parsing 'ils' output");
     }
 
     my $mtime = $1;
@@ -323,7 +322,8 @@ sub write_file {
     $meta_int = $1 if ($meta_int =~ /^(\d+)-\d+(-\d+)?$/);
     local *OUT;
     Exec::exec_pipe(*OUT,
-        "'$::TSKDIR/ils' -s $Caseman::ts -f $ftype -e -o $offset -i $imgtype $img $meta_int");
+"'$::TSKDIR/ils' -s $Caseman::ts -f $ftype -e -o $offset -i $imgtype $img $meta_int"
+    );
 
     # Skip to the fourth line
     my $tmp = Exec::read_pipe_line(*OUT);
@@ -333,7 +333,7 @@ sub write_file {
     unless ((defined $tmp)
         && ($tmp =~ /^$::REG_META\|\w\|\d+\|\d+\|(\d+)\|(\d+)\|(\d+)\|/o))
     {
-        Print::print_err("Error parsing 'ils' output<br>");
+        Print::print_err("Error parsing 'ils' output");
     }
     my $mtime = $1;
     my $atime = $2;
@@ -625,10 +625,11 @@ sub write_seq_man {
     $Args::args{'note'} =~ s/\n/<br>/gs;
 
     if ($Args::args{'note'} eq "") {
-        Print::print_err("A comment must be given for the event<br>\n"
+        print(  "A comment must be given for the event<br>\n"
               . "<p><a href=\"$::PROGNAME?mod=$::MOD_NOTES&view=$Notes::READ_SEQ&$Args::baseargs\">"
               . "<img border=0 src=\"pict/menu_b_ok.jpg\" "
               . "width=167 height=20></a>");
+        Print::print_err("\n");
     }
 
     # Check the args and add them to the final string that will be written
@@ -636,38 +637,38 @@ sub write_seq_man {
     unless ((exists $Args::args{'year'})
         && ($Args::args{'year'} =~ /^(\d\d\d\d)$/))
     {
-        Print::print_err("Invalid year<br>");
+        Print::print_err("Invalid year");
     }
     $str .= "'$1',";
 
     unless ((exists $Args::args{'mon'}) && ($Args::args{'mon'} =~ /^(\d\d?)$/))
     {
-        Print::print_err("Invalid month<br>");
+        Print::print_err("Invalid month");
     }
     $str .= "'$1',";
 
     unless ((exists $Args::args{'day'}) && ($Args::args{'day'} =~ /^(\d\d?)$/))
     {
-        Print::print_err("Invalid day<br>");
+        Print::print_err("Invalid day");
     }
     $str .= "'$1',";
 
     unless ((exists $Args::args{'hour'})
         && ($Args::args{'hour'} =~ /^(\d\d?)$/))
     {
-        Print::print_err("Invalid hour<br>");
+        Print::print_err("Invalid hour");
     }
     $str .= "'$1',";
 
     unless ((exists $Args::args{'min'}) && ($Args::args{'min'} =~ /^(\d\d?)$/))
     {
-        Print::print_err("Invalid min<br>");
+        Print::print_err("Invalid min");
     }
     $str .= "'$1',";
 
     unless ((exists $Args::args{'sec'}) && ($Args::args{'sec'} =~ /^(\d\d?)$/))
     {
-        Print::print_err("Invalid sec<br>");
+        Print::print_err("Invalid sec");
     }
     $str .= "'$1',";
 
@@ -675,7 +676,7 @@ sub write_seq_man {
     $str .= "'$Args::args{'host'}','','','','',";
 
     unless ((exists $Args::args{'src'}) && ($Args::args{'src'} =~ /^(\w+)$/)) {
-        Print::print_err("Invalid src<br>");
+        Print::print_err("Invalid src");
     }
     $str .= "'$1','$Args::args{'note'}'\n";
 
